@@ -153,7 +153,7 @@ def cleanup_filename(
         banned_chars.remove(os.path.sep)
 
     for char in banned_chars:
-        filename.replace(char, "_")
+        filename = filename.replace(char, "_")
 
     if full_path:
         filename_clean = os.path.sep
@@ -176,7 +176,7 @@ def cleanup_filename(
             if i == (len(filename_split) - 1):
                 # If we're dealing with a filename, keep the extension
                 f, ext = os.path.splitext(f)
-                f = f[(-249 - len(ext)) :] + ext
+                f = f[(-249 + len(ext) - 1) :] + ext
             else:
                 f = f[-249:]
 
@@ -214,8 +214,6 @@ def filename_valid(
             return False
 
     for f in filename.split(os.path.sep):
-        if f == "":
-            continue
         if (
             f in BANNED_FILENAMES + ("..",)
             or f.endswith(".")
@@ -235,3 +233,36 @@ def file_is_sandboxed(path: str) -> bool:
     to work under Flatpak.
     """
     return bool(re.match("^/run/user/[0-9].*/doc", path))
+
+
+def natural_compare(a: str, b: str) -> int:
+    """
+    Compares two strings using the "natural/human sorting" algorithm.
+
+    This returns an integer, satisfying similar constraints to GLib's collate
+    functions: 0 if both strings are the same, 1 if a > b, and -1 if a < b.
+    """
+    a = a.lower()
+    b = b.lower()
+    if a == b:
+        return 0
+
+    # adapted from https://stackoverflow.com/questions/2545532
+    def sort_key(s: str) -> list:
+        out = []
+        for x in s:
+            if x.isdecimal():
+                out.append(int(x))
+            else:
+                try:
+                    out[-1] += x
+                except (IndexError, TypeError):
+                    out.append(x)
+        if out[-1] == "":
+            return out[:-1]
+        return out
+
+    sort = sorted([a, b], key=sort_key)
+    if sort[0] == a:
+        return -1
+    return 1
