@@ -64,7 +64,6 @@ class EartagWindow(Adw.ApplicationWindow):
     sidebar_headerbar = Gtk.Template.Child()
     sidebar_search_button = Gtk.Template.Child()
     select_multiple_button = Gtk.Template.Child()
-    sort_button = Gtk.Template.Child()
 
     no_file = Gtk.Template.Child()
     file_view = Gtk.Template.Child()
@@ -223,6 +222,7 @@ class EartagWindow(Adw.ApplicationWindow):
         if selected_files_count <= 0:
             try:
                 for action in (
+                    app.sort_action,
                     app.rename_action,
                     app.extract_action,
                     app.identify_action,
@@ -253,7 +253,8 @@ class EartagWindow(Adw.ApplicationWindow):
             self.set_title("{f} — Ear Tag".format(f=file_basename))
             self.window_title.set_subtitle(file_basename)
         else:
-            # TRANSLATOR: Placeholder for file path when multiple files are selected
+            # TRANSLATORS: Placeholder for file path when multiple files are selected.
+            # Shows up in the titlebar of the application.
             _multiple_files = _("(Multiple files selected)")
             self.set_title("{f} — Ear Tag".format(f=_multiple_files))
             self.window_title.set_subtitle(_multiple_files)
@@ -267,6 +268,7 @@ class EartagWindow(Adw.ApplicationWindow):
         try:
             app.undo_all_action.set_enabled(is_modified)
             for action in (
+                app.sort_action,
                 app.rename_action,
                 app.extract_action,
                 app.identify_action,
@@ -309,9 +311,10 @@ class EartagWindow(Adw.ApplicationWindow):
             self.drop_target.reject()
             self.on_drag_unhover()
             return False
+
         for file in files:
             path = file.get_path()
-            if not is_valid_music_file(path):
+            if not os.path.isdir(path) and not is_valid_music_file(path):
                 self.drop_target.reject()
                 self.on_drag_unhover()
 
@@ -327,11 +330,9 @@ class EartagWindow(Adw.ApplicationWindow):
 
     def on_drag_drop(self, drop_target, value, *args):
         files = value.get_files()
-        paths = []
-        for file in files:
-            paths.append(file.get_path())
+
         self.open_mode = EartagFileManager.LOAD_INSERT
-        self.open_files(paths)
+        self.load_files_from_paths([f.get_path() for f in files])
         self.open_mode = EartagFileManager.LOAD_OVERWRITE
         self.on_drag_unhover()
 
@@ -377,8 +378,8 @@ class EartagWindow(Adw.ApplicationWindow):
             self.open_mode != EartagFileManager.LOAD_INSERT
             and self.file_manager._is_modified
         ):
-            self.discard_warning = EartagDiscardWarningDialog(self, paths)
-            self.discard_warning.show()
+            self.discard_warning = EartagDiscardWarningDialog(self.file_manager, paths)
+            self.discard_warning.present(self)
             return False
 
         self.file_manager.load_files(paths, mode=self.open_mode)
@@ -405,21 +406,26 @@ class EartagWindow(Adw.ApplicationWindow):
         if not response:
             return
 
-        paths = []
-        for file in response:
-            _path = file.get_path()
-            if os.path.isdir(_path):
-                for _file in os.listdir(_path):
-                    _fpath = os.path.join(_path, _file)
-                    if os.path.isfile(_fpath) and is_valid_music_file(_fpath):
-                        paths.append(_fpath)
+        return self.load_files_from_paths([f.get_path() for f in response])
+
+    def load_files_from_paths(self, paths):
+        """Loads files from a list of paths: handles both files and folders."""
+        paths_valid = []
+        for path in paths:
+            if os.path.isdir(path):
+                for file in os.listdir(path):
+                    fpath = os.path.join(path, file)
+                    if os.path.isfile(fpath) and is_valid_music_file(fpath):
+                        paths_valid.append(fpath)
             else:
-                paths.append(_path)
-        if not paths:
+                paths_valid.append(path)
+
+        if not paths_valid:
             toast = Adw.Toast.new(_("No supported files found in opened folder"))
             self.toast_overlay.add_toast(toast)
             return
-        return self.open_files(paths)
+
+        return self.open_files(paths_valid)
 
     def toggle_save_button(self, *args):
         if self.file_manager.has_error:
@@ -442,7 +448,6 @@ class EartagWindow(Adw.ApplicationWindow):
     def hide_sidebar(self, *args):
         self.split_view.set_show_sidebar(False)
 
-    @Gtk.Template.Callback()
     def run_sort(self, *args):
         if self.file_manager.files.get_n_items():
             self.file_manager.sorter.changed(Gtk.SorterChange.DIFFERENT)
@@ -463,8 +468,8 @@ class EartagWindow(Adw.ApplicationWindow):
             and list(self.file_manager.files)
             and self.file_manager._is_modified
         ):
-            self.close_request_dialog = EartagCloseWarningDialog(self)
-            self.close_request_dialog.present()
+            self.close_request_dialog = EartagCloseWarningDialog(self.file_manager)
+            self.close_request_dialog.present(self)
             return True
 
         MusicBrainzRelease.clear_tempfiles()
@@ -479,23 +484,23 @@ class EartagWindow(Adw.ApplicationWindow):
 
     def show_rename_dialog(self, *args):
         self.rename_dialog = EartagRenameDialog(self)
-        self.rename_dialog.present()
+        self.rename_dialog.present(self)
 
     def show_identify_dialog(self, *args):
         self.identify_dialog = EartagIdentifyDialog(self)
-        self.identify_dialog.present()
+        self.identify_dialog.present(self)
 
-    def show_settings_dialog(self, *args):
-        self.settings_dialog = EartagSettingsWindow(self)
-        self.settings_dialog.present()
+    def show_preferences_dialog(self, *args):
+        self.preferences_dialog = EartagPreferencesDialog()
+        self.preferences_dialog.present(self)
 
     def show_extract_dialog(self, *args):
         self.extract_dialog = EartagExtractTagsDialog(self)
-        self.extract_dialog.present()
+        self.extract_dialog.present(self)
 
     def show_delete_all_tags_dialog(self, *args):
         self.delete_all_tags_dialog = EartagTagDeleteWarningDialog(self)
-        self.delete_all_tags_dialog.present()
+        self.delete_all_tags_dialog.present(self)
 
     # Sidebar
 
@@ -560,6 +565,8 @@ class EartagWindow(Adw.ApplicationWindow):
                 selected_message = _("No files selected")
                 self.remove_selected_button.set_sensitive(False)
             else:
+                # TRANSLATORS: {n} is a placeholder for the amount of files.
+                # **Do not change the letter between the curly brackets!**
                 selected_message = gettext.ngettext(
                     "1 file selected", "{n} files selected", selected_file_count
                 ).format(n=selected_file_count)
@@ -639,6 +646,8 @@ class EartagWindow(Adw.ApplicationWindow):
         self.set_sensitive(True)
 
         toast = Adw.Toast.new(
+            # TRANSLATORS: {n} is a placeholder for the amount of files.
+            # **Do not change the letter between the curly brackets!**
             gettext.ngettext(
                 "Undid changes in 1 file",
                 "Undid changes in {n} files",
@@ -673,6 +682,8 @@ class EartagWindow(Adw.ApplicationWindow):
         self.file_view.more_tags_group.slow_refresh_entries()
         self.set_sensitive(True)
         toast = Adw.Toast.new(
+            # TRANSLATORS: {n} is a placeholder for the amount of files.
+            # **Do not change the letter between the curly brackets!**
             gettext.ngettext(
                 "Redid changes in 1 file",
                 "Redid changes in {n} files",
@@ -718,6 +729,9 @@ class EartagWindow(Adw.ApplicationWindow):
         self.set_sensitive(True)
 
         toast = Adw.Toast.new(
+            # TRANSLATORS: {n} is a placeholder for the amount of files
+            # that tags have been removed from.
+            # **Do not change the letter between the curly brackets!**
             gettext.ngettext(
                 "Removed tags from 1 file",
                 "Removed tags from {n} files",
@@ -751,6 +765,8 @@ class EartagWindow(Adw.ApplicationWindow):
         self.set_sensitive(True)
 
         toast = Adw.Toast.new(
+            # TRANSLATORS: {n} is a placeholder for the amount of files.
+            # **Do not change the letter between the curly brackets!**
             gettext.ngettext(
                 "Undid tag removal in 1 file",
                 "Undid tag removal in {n} files",
@@ -764,15 +780,15 @@ class EartagWindow(Adw.ApplicationWindow):
 
 
 @Gtk.Template(resource_path=f"{APP_GRESOURCE_PATH}/ui/settings.ui")
-class EartagSettingsWindow(Adw.PreferencesWindow):
-    __gtype_name__ = "EartagSettingsWindow"
+class EartagPreferencesDialog(Adw.PreferencesDialog):
+    __gtype_name__ = "EartagPreferencesDialog"
 
     mb_confidence_spinbutton = Gtk.Template.Child()
     aid_confidence_spinbutton = Gtk.Template.Child()
     cover_size_comborow = Gtk.Template.Child()
 
-    def __init__(self, parent):
-        super().__init__(transient_for=parent, modal=True)
+    def __init__(self):
+        super().__init__()
 
         config.bind(
             "musicbrainz-confidence-treshold",
